# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from smart_diagnostics_client.api_client import ApiClient


class UsersApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_corporation_permission(self, user_id, **kwargs):  # noqa: E501
        """add_corporation_permission  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_corporation_permission(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: (required)
        :param CorporationPermissionCreateRequest body:
        :return: UserResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.add_corporation_permission_with_http_info(user_id, **kwargs)  # noqa: E501
        else:
            (data) = self.add_corporation_permission_with_http_info(user_id, **kwargs)  # noqa: E501
            return data

    def add_corporation_permission_with_http_info(self, user_id, **kwargs):  # noqa: E501
        """add_corporation_permission  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_corporation_permission_with_http_info(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: (required)
        :param CorporationPermissionCreateRequest body:
        :return: UserResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_corporation_permission" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_id' is set
        if ('user_id' not in params or
                params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `add_corporation_permission`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'user_id' in params:
            path_params['userId'] = params['user_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Users/{userId}/permissions/corporations', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def add_location_permission(self, user_id, **kwargs):  # noqa: E501
        """Adds a location permission for the specified user  # noqa: E501

        Required Permissions: Location Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_location_permission(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: Id of the user (required)
        :param LocationPermissionCreateRequest body: A request to add a location permission to the given user
        :return: UserResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.add_location_permission_with_http_info(user_id, **kwargs)  # noqa: E501
        else:
            (data) = self.add_location_permission_with_http_info(user_id, **kwargs)  # noqa: E501
            return data

    def add_location_permission_with_http_info(self, user_id, **kwargs):  # noqa: E501
        """Adds a location permission for the specified user  # noqa: E501

        Required Permissions: Location Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_location_permission_with_http_info(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: Id of the user (required)
        :param LocationPermissionCreateRequest body: A request to add a location permission to the given user
        :return: UserResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_location_permission" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_id' is set
        if ('user_id' not in params or
                params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `add_location_permission`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'user_id' in params:
            path_params['userId'] = params['user_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Users/{userId}/permissions/locations', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def check_email_exists(self, email, **kwargs):  # noqa: E501
        """Checks if the given email exists  # noqa: E501

        Required Permissions: User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.check_email_exists(email, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str email: The email to check (required)
        :return: bool
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.check_email_exists_with_http_info(email, **kwargs)  # noqa: E501
        else:
            (data) = self.check_email_exists_with_http_info(email, **kwargs)  # noqa: E501
            return data

    def check_email_exists_with_http_info(self, email, **kwargs):  # noqa: E501
        """Checks if the given email exists  # noqa: E501

        Required Permissions: User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.check_email_exists_with_http_info(email, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str email: The email to check (required)
        :return: bool
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['email']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method check_email_exists" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'email' is set
        if ('email' not in params or
                params['email'] is None):
            raise ValueError("Missing the required parameter `email` when calling `check_email_exists`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'email' in params:
            path_params['email'] = params['email']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Users/{email}/exists', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='bool',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def confirm_password_sd4(self, **kwargs):  # noqa: E501
        """Confirms a user's new password when user resets their password.  # noqa: E501

        Required Permissions: None  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.confirm_password_sd4(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UserConfirmPasswordRequest body: The confirm password request
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.confirm_password_sd4_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.confirm_password_sd4_with_http_info(**kwargs)  # noqa: E501
            return data

    def confirm_password_sd4_with_http_info(self, **kwargs):  # noqa: E501
        """Confirms a user's new password when user resets their password.  # noqa: E501

        Required Permissions: None  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.confirm_password_sd4_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UserConfirmPasswordRequest body: The confirm password request
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method confirm_password_sd4" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Users/password/confirm', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_user(self, **kwargs):  # noqa: E501
        """Create a new user  # noqa: E501

        Required Permissions:  - System admin can create any type of user  - Sentry can create sentry and below  - Corporation admins can create corporation admins and below  - Location admins can create location admins and below  - Users without admin rights cannot create users  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_user(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UserCreateRequest body: Request to create a new user
        :return: UserResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_user_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.create_user_with_http_info(**kwargs)  # noqa: E501
            return data

    def create_user_with_http_info(self, **kwargs):  # noqa: E501
        """Create a new user  # noqa: E501

        Required Permissions:  - System admin can create any type of user  - Sentry can create sentry and below  - Corporation admins can create corporation admins and below  - Location admins can create location admins and below  - Users without admin rights cannot create users  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_user_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UserCreateRequest body: Request to create a new user
        :return: UserResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_user" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Users', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_corporation_permission(self, user_id, corporation_id, **kwargs):  # noqa: E501
        """Deletes a specific corporation permission  # noqa: E501

        Required Permissions: Corporation Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_corporation_permission(user_id, corporation_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: Id of the user associated with the permission (required)
        :param str corporation_id: Id of the permission (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_corporation_permission_with_http_info(user_id, corporation_id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_corporation_permission_with_http_info(user_id, corporation_id, **kwargs)  # noqa: E501
            return data

    def delete_corporation_permission_with_http_info(self, user_id, corporation_id, **kwargs):  # noqa: E501
        """Deletes a specific corporation permission  # noqa: E501

        Required Permissions: Corporation Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_corporation_permission_with_http_info(user_id, corporation_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: Id of the user associated with the permission (required)
        :param str corporation_id: Id of the permission (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id', 'corporation_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_corporation_permission" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_id' is set
        if ('user_id' not in params or
                params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `delete_corporation_permission`")  # noqa: E501
        # verify the required parameter 'corporation_id' is set
        if ('corporation_id' not in params or
                params['corporation_id'] is None):
            raise ValueError("Missing the required parameter `corporation_id` when calling `delete_corporation_permission`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'user_id' in params:
            path_params['userId'] = params['user_id']  # noqa: E501
        if 'corporation_id' in params:
            path_params['corporationId'] = params['corporation_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Users/{userId}/permissions/corporations/{corporationId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_location_permission(self, user_id, location_id, **kwargs):  # noqa: E501
        """Deletes a specific location permission  # noqa: E501

        Required Permissions: Location Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_location_permission(user_id, location_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: Id of the user associated with the permission (required)
        :param str location_id: Id of the permission (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_location_permission_with_http_info(user_id, location_id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_location_permission_with_http_info(user_id, location_id, **kwargs)  # noqa: E501
            return data

    def delete_location_permission_with_http_info(self, user_id, location_id, **kwargs):  # noqa: E501
        """Deletes a specific location permission  # noqa: E501

        Required Permissions: Location Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_location_permission_with_http_info(user_id, location_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: Id of the user associated with the permission (required)
        :param str location_id: Id of the permission (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id', 'location_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_location_permission" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_id' is set
        if ('user_id' not in params or
                params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `delete_location_permission`")  # noqa: E501
        # verify the required parameter 'location_id' is set
        if ('location_id' not in params or
                params['location_id'] is None):
            raise ValueError("Missing the required parameter `location_id` when calling `delete_location_permission`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'user_id' in params:
            path_params['userId'] = params['user_id']  # noqa: E501
        if 'location_id' in params:
            path_params['locationId'] = params['location_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Users/{userId}/permissions/locations/{locationId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_personal_access_token(self, token_id, **kwargs):  # noqa: E501
        """Revokes one of the current user's access tokens.  # noqa: E501

        Required Permissions: User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_personal_access_token(token_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str token_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_personal_access_token_with_http_info(token_id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_personal_access_token_with_http_info(token_id, **kwargs)  # noqa: E501
            return data

    def delete_personal_access_token_with_http_info(self, token_id, **kwargs):  # noqa: E501
        """Revokes one of the current user's access tokens.  # noqa: E501

        Required Permissions: User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_personal_access_token_with_http_info(token_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str token_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['token_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_personal_access_token" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'token_id' is set
        if ('token_id' not in params or
                params['token_id'] is None):
            raise ValueError("Missing the required parameter `token_id` when calling `delete_personal_access_token`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'token_id' in params:
            path_params['tokenId'] = params['token_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Users/currentUser/tokens/{tokenId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def generate_personal_access_tokens(self, **kwargs):  # noqa: E501
        """Generate a new access token for the current user.  # noqa: E501

        Required Permissions: User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.generate_personal_access_tokens(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PersonalAccessTokenCreateRequest body:
        :return: PersonalAccessTokenCreateResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.generate_personal_access_tokens_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.generate_personal_access_tokens_with_http_info(**kwargs)  # noqa: E501
            return data

    def generate_personal_access_tokens_with_http_info(self, **kwargs):  # noqa: E501
        """Generate a new access token for the current user.  # noqa: E501

        Required Permissions: User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.generate_personal_access_tokens_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PersonalAccessTokenCreateRequest body:
        :return: PersonalAccessTokenCreateResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method generate_personal_access_tokens" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Users/currentUser/tokens', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PersonalAccessTokenCreateResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_current_user(self, **kwargs):  # noqa: E501
        """Gets the Current user  # noqa: E501

        Required Permissions: User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_current_user(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: CurrentUserResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_current_user_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_current_user_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_current_user_with_http_info(self, **kwargs):  # noqa: E501
        """Gets the Current user  # noqa: E501

        Required Permissions: User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_current_user_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: CurrentUserResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_current_user" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Users/currentUser', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CurrentUserResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_personal_access_token(self, token_id, **kwargs):  # noqa: E501
        """Get one of the current user's access tokens.  # noqa: E501

        Required Permissions: User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_personal_access_token(token_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str token_id: (required)
        :return: PersonalAccessTokenResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_personal_access_token_with_http_info(token_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_personal_access_token_with_http_info(token_id, **kwargs)  # noqa: E501
            return data

    def get_personal_access_token_with_http_info(self, token_id, **kwargs):  # noqa: E501
        """Get one of the current user's access tokens.  # noqa: E501

        Required Permissions: User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_personal_access_token_with_http_info(token_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str token_id: (required)
        :return: PersonalAccessTokenResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['token_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_personal_access_token" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'token_id' is set
        if ('token_id' not in params or
                params['token_id'] is None):
            raise ValueError("Missing the required parameter `token_id` when calling `get_personal_access_token`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'token_id' in params:
            path_params['tokenId'] = params['token_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Users/currentUser/tokens/{tokenId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PersonalAccessTokenResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_personal_access_tokens(self, **kwargs):  # noqa: E501
        """Lists the current user's access tokens.  # noqa: E501

        Required Permissions: User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_personal_access_tokens(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `Active` | Boolean | `eq, neq` | | `Created` | DateTime | `eq, neq, in, lt, gt, leq, geq` | | `Description` | String | `eq, neq, in, like, isnull, isnotnull` | | `LastUsed` | DateTime? | `eq, neq, in, lt, gt, leq, geq, isnull, isnotnull` | | `Updated` | DateTime? | `eq, neq, in, lt, gt, leq, geq, isnull, isnotnull` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `Active` | Boolean | | `Created` | DateTime | | `Description` | String | | `LastUsed` | DateTime? | | `Updated` | DateTime? |
        :param str name_search: Provide search terms to narrow result.  Searchable properties: `Description`.
        :return: PagedResultsModelPersonalAccessTokenResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_personal_access_tokens_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_personal_access_tokens_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_personal_access_tokens_with_http_info(self, **kwargs):  # noqa: E501
        """Lists the current user's access tokens.  # noqa: E501

        Required Permissions: User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_personal_access_tokens_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `Active` | Boolean | `eq, neq` | | `Created` | DateTime | `eq, neq, in, lt, gt, leq, geq` | | `Description` | String | `eq, neq, in, like, isnull, isnotnull` | | `LastUsed` | DateTime? | `eq, neq, in, lt, gt, leq, geq, isnull, isnotnull` | | `Updated` | DateTime? | `eq, neq, in, lt, gt, leq, geq, isnull, isnotnull` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `Active` | Boolean | | `Created` | DateTime | | `Description` | String | | `LastUsed` | DateTime? | | `Updated` | DateTime? |
        :param str name_search: Provide search terms to narrow result.  Searchable properties: `Description`.
        :return: PagedResultsModelPersonalAccessTokenResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['filter', 'page', 'page_limit', 'order_by', 'name_search']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_personal_access_tokens" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'filter' in params:
            query_params.append(('Filter', params['filter']))  # noqa: E501
        if 'page' in params:
            query_params.append(('Page', params['page']))  # noqa: E501
        if 'page_limit' in params:
            query_params.append(('PageLimit', params['page_limit']))  # noqa: E501
        if 'order_by' in params:
            query_params.append(('OrderBy', params['order_by']))  # noqa: E501
        if 'name_search' in params:
            query_params.append(('NameSearch', params['name_search']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Users/currentUser/tokens', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PagedResultsModelPersonalAccessTokenResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_profile_options(self, **kwargs):  # noqa: E501
        """Gets all possible options for user profile properties  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_profile_options(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: ProfileOptionsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_profile_options_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_profile_options_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_profile_options_with_http_info(self, **kwargs):  # noqa: E501
        """Gets all possible options for user profile properties  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_profile_options_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: ProfileOptionsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_profile_options" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Users/profiles/options', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ProfileOptionsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_user(self, user_id, **kwargs):  # noqa: E501
        """Returns a specified user  # noqa: E501

        Required Permissions:  - System admin and Sentry can get any user  - Corporation admins can get other corporation admins and users in their corporation as    well as location admins and users in the locations under their corporation  - Corporation users can get other corporation users in their corporation  - Location admins can get other location admins and location users in their location  - Location users can get other location users in their location  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_user(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: The Id of the User to return (required)
        :return: UserResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_user_with_http_info(user_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_user_with_http_info(user_id, **kwargs)  # noqa: E501
            return data

    def get_user_with_http_info(self, user_id, **kwargs):  # noqa: E501
        """Returns a specified user  # noqa: E501

        Required Permissions:  - System admin and Sentry can get any user  - Corporation admins can get other corporation admins and users in their corporation as    well as location admins and users in the locations under their corporation  - Corporation users can get other corporation users in their corporation  - Location admins can get other location admins and location users in their location  - Location users can get other location users in their location  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_user_with_http_info(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: The Id of the User to return (required)
        :return: UserResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_user" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_id' is set
        if ('user_id' not in params or
                params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `get_user`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'user_id' in params:
            path_params['userId'] = params['user_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Users/{userId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_user_locations(self, user_id, **kwargs):  # noqa: E501
        """Returns a paged list of all locations that the selected user and accessing user both have access to  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_user_locations(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: UserId of user to return locations for. (required)
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `Abbreviation` | String | `eq, neq, in, like, isnull, isnotnull` | | `Active` | Boolean | `eq, neq` | | `CorporationAbbreviation` | String | `eq, neq, in, like, isnull, isnotnull` | | `CorporationId` | Guid | `eq, neq, in` | | `CorporationName` | String | `eq, neq, in, like, isnull, isnotnull` | | `Id` | Guid | `eq, neq, in` | | `Name` | String | `eq, neq, in, like, isnull, isnotnull` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `Abbreviation` | String | | `Active` | Boolean | | `CorporationName` | String | | `Name` | String |
        :param str name_search: Provide search terms to narrow result.  Searchable properties: `Abbreviation`, `CorporationName`, `Name`.
        :return: PagedResultsModelLocationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_user_locations_with_http_info(user_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_user_locations_with_http_info(user_id, **kwargs)  # noqa: E501
            return data

    def get_user_locations_with_http_info(self, user_id, **kwargs):  # noqa: E501
        """Returns a paged list of all locations that the selected user and accessing user both have access to  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_user_locations_with_http_info(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: UserId of user to return locations for. (required)
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `Abbreviation` | String | `eq, neq, in, like, isnull, isnotnull` | | `Active` | Boolean | `eq, neq` | | `CorporationAbbreviation` | String | `eq, neq, in, like, isnull, isnotnull` | | `CorporationId` | Guid | `eq, neq, in` | | `CorporationName` | String | `eq, neq, in, like, isnull, isnotnull` | | `Id` | Guid | `eq, neq, in` | | `Name` | String | `eq, neq, in, like, isnull, isnotnull` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `Abbreviation` | String | | `Active` | Boolean | | `CorporationName` | String | | `Name` | String |
        :param str name_search: Provide search terms to narrow result.  Searchable properties: `Abbreviation`, `CorporationName`, `Name`.
        :return: PagedResultsModelLocationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id', 'filter', 'page', 'page_limit', 'order_by', 'name_search']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_user_locations" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_id' is set
        if ('user_id' not in params or
                params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `get_user_locations`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'user_id' in params:
            path_params['userId'] = params['user_id']  # noqa: E501

        query_params = []
        if 'filter' in params:
            query_params.append(('Filter', params['filter']))  # noqa: E501
        if 'page' in params:
            query_params.append(('Page', params['page']))  # noqa: E501
        if 'page_limit' in params:
            query_params.append(('PageLimit', params['page_limit']))  # noqa: E501
        if 'order_by' in params:
            query_params.append(('OrderBy', params['order_by']))  # noqa: E501
        if 'name_search' in params:
            query_params.append(('NameSearch', params['name_search']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Users/{userId}/Locations', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PagedResultsModelLocationResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_user_profile(self, user_id, **kwargs):  # noqa: E501
        """Gets a user's profile  # noqa: E501

        Required Permissions:  - System admin and Sentry can get any user  - Corporation admins can get other corporation admins and users in their corporation as    well as location admins and users in the locations under their corporation  - Corporation users can get other corporation users in their corporation  - Location admins can get other location admins and location users in their location  - Location users can get other location users in their location  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_user_profile(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: The user's ID (required)
        :return: UserProfileResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_user_profile_with_http_info(user_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_user_profile_with_http_info(user_id, **kwargs)  # noqa: E501
            return data

    def get_user_profile_with_http_info(self, user_id, **kwargs):  # noqa: E501
        """Gets a user's profile  # noqa: E501

        Required Permissions:  - System admin and Sentry can get any user  - Corporation admins can get other corporation admins and users in their corporation as    well as location admins and users in the locations under their corporation  - Corporation users can get other corporation users in their corporation  - Location admins can get other location admins and location users in their location  - Location users can get other location users in their location  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_user_profile_with_http_info(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: The user's ID (required)
        :return: UserProfileResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_user_profile" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_id' is set
        if ('user_id' not in params or
                params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `get_user_profile`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'user_id' in params:
            path_params['userId'] = params['user_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Users/{userId}/profile', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserProfileResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_users(self, **kwargs):  # noqa: E501
        """Returns a paged list of all users  # noqa: E501

        - Global admin, Sentry, and Sales can get any user  - Corporation admins and corporation users can get other corporation admins and users in their corporation as    well as location admins and users in the locations under their corporation  - Location admins and location users can get other location admins and location users in their location  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_users(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[str] corporation_ids: A list of corporation IDs to filter the result
        :param list[str] location_ids: A list of location IDs to filter the result
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `AcceptedEula` | Boolean | `eq, neq` | | `ApplicationRoleCode` | ApplicationRoleCode | `eq, neq, in` | | `Email` | String | `eq, neq, in, like, isnull, isnotnull` | | `FirstName` | String | `eq, neq, in, like, isnull, isnotnull` | | `IsApproved` | Boolean | `eq, neq` | | `LastLogin` | DateTime? | `eq, neq, in, lt, gt, leq, geq, isnull, isnotnull` | | `LastName` | String | `eq, neq, in, like, isnull, isnotnull` | | `LockedOut` | Boolean | `eq, neq` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `AcceptedEula` | Boolean | | `ApplicationRoleCode` | ApplicationRoleCode | | `Email` | String | | `FirstName` | String | | `IsApproved` | Boolean | | `LastLogin` | DateTime? | | `LastName` | String | | `LockedOut` | Boolean |
        :param str name_search: Provide search terms to narrow result.  Searchable properties: `Email`, `FirstName`, `FullName`, `LastName`, `PhoneNumber`.
        :return: PagedResultsModelUserResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_users_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_users_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_users_with_http_info(self, **kwargs):  # noqa: E501
        """Returns a paged list of all users  # noqa: E501

        - Global admin, Sentry, and Sales can get any user  - Corporation admins and corporation users can get other corporation admins and users in their corporation as    well as location admins and users in the locations under their corporation  - Location admins and location users can get other location admins and location users in their location  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_users_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[str] corporation_ids: A list of corporation IDs to filter the result
        :param list[str] location_ids: A list of location IDs to filter the result
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `AcceptedEula` | Boolean | `eq, neq` | | `ApplicationRoleCode` | ApplicationRoleCode | `eq, neq, in` | | `Email` | String | `eq, neq, in, like, isnull, isnotnull` | | `FirstName` | String | `eq, neq, in, like, isnull, isnotnull` | | `IsApproved` | Boolean | `eq, neq` | | `LastLogin` | DateTime? | `eq, neq, in, lt, gt, leq, geq, isnull, isnotnull` | | `LastName` | String | `eq, neq, in, like, isnull, isnotnull` | | `LockedOut` | Boolean | `eq, neq` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `AcceptedEula` | Boolean | | `ApplicationRoleCode` | ApplicationRoleCode | | `Email` | String | | `FirstName` | String | | `IsApproved` | Boolean | | `LastLogin` | DateTime? | | `LastName` | String | | `LockedOut` | Boolean |
        :param str name_search: Provide search terms to narrow result.  Searchable properties: `Email`, `FirstName`, `FullName`, `LastName`, `PhoneNumber`.
        :return: PagedResultsModelUserResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['corporation_ids', 'location_ids', 'filter', 'page', 'page_limit', 'order_by', 'name_search']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_users" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'corporation_ids' in params:
            query_params.append(('corporationIds', params['corporation_ids']))  # noqa: E501
            collection_formats['corporationIds'] = 'multi'  # noqa: E501
        if 'location_ids' in params:
            query_params.append(('locationIds', params['location_ids']))  # noqa: E501
            collection_formats['locationIds'] = 'multi'  # noqa: E501
        if 'filter' in params:
            query_params.append(('Filter', params['filter']))  # noqa: E501
        if 'page' in params:
            query_params.append(('Page', params['page']))  # noqa: E501
        if 'page_limit' in params:
            query_params.append(('PageLimit', params['page_limit']))  # noqa: E501
        if 'order_by' in params:
            query_params.append(('OrderBy', params['order_by']))  # noqa: E501
        if 'name_search' in params:
            query_params.append(('NameSearch', params['name_search']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Users', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PagedResultsModelUserResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def reset_password_sd4(self, **kwargs):  # noqa: E501
        """Requests that a users password be reset. The users will receive an email with  instructions on how to reset their password.  # noqa: E501

        Required Permissions: None  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.reset_password_sd4(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str body: The User's email
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.reset_password_sd4_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.reset_password_sd4_with_http_info(**kwargs)  # noqa: E501
            return data

    def reset_password_sd4_with_http_info(self, **kwargs):  # noqa: E501
        """Requests that a users password be reset. The users will receive an email with  instructions on how to reset their password.  # noqa: E501

        Required Permissions: None  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.reset_password_sd4_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str body: The User's email
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method reset_password_sd4" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Users/password/reset', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def send_confirmation_code(self, **kwargs):  # noqa: E501
        """Sends a confirmation code to the supplied phone number  # noqa: E501

        Required Permissions: User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.send_confirmation_code(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UserPhoneNumberConfirmRequest body: The request object containing the phone number to send the confirmation code to
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.send_confirmation_code_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.send_confirmation_code_with_http_info(**kwargs)  # noqa: E501
            return data

    def send_confirmation_code_with_http_info(self, **kwargs):  # noqa: E501
        """Sends a confirmation code to the supplied phone number  # noqa: E501

        Required Permissions: User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.send_confirmation_code_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UserPhoneNumberConfirmRequest body: The request object containing the phone number to send the confirmation code to
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method send_confirmation_code" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Users/phoneNumber/confirm', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def unlock_user(self, user_id, **kwargs):  # noqa: E501
        """Unlocks the user with the specified id (Sets LockedOut to false)  # noqa: E501

        Required Permissions: System Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.unlock_user(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: ID of user whose lock value will be updated (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.unlock_user_with_http_info(user_id, **kwargs)  # noqa: E501
        else:
            (data) = self.unlock_user_with_http_info(user_id, **kwargs)  # noqa: E501
            return data

    def unlock_user_with_http_info(self, user_id, **kwargs):  # noqa: E501
        """Unlocks the user with the specified id (Sets LockedOut to false)  # noqa: E501

        Required Permissions: System Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.unlock_user_with_http_info(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: ID of user whose lock value will be updated (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method unlock_user" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_id' is set
        if ('user_id' not in params or
                params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `unlock_user`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'user_id' in params:
            path_params['userId'] = params['user_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Users/{userId}/unlock', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_corporation_permission(self, user_id, corporation_id, **kwargs):  # noqa: E501
        """Updates an existing user's corporation permission  # noqa: E501

        Required Permissions: Corporation Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_corporation_permission(user_id, corporation_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: Id of the user (required)
        :param str corporation_id: Id of the corporation (required)
        :param CorporationPermissionUpdateRequest body: Request to modify the permission
        :return: UserResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_corporation_permission_with_http_info(user_id, corporation_id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_corporation_permission_with_http_info(user_id, corporation_id, **kwargs)  # noqa: E501
            return data

    def update_corporation_permission_with_http_info(self, user_id, corporation_id, **kwargs):  # noqa: E501
        """Updates an existing user's corporation permission  # noqa: E501

        Required Permissions: Corporation Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_corporation_permission_with_http_info(user_id, corporation_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: Id of the user (required)
        :param str corporation_id: Id of the corporation (required)
        :param CorporationPermissionUpdateRequest body: Request to modify the permission
        :return: UserResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id', 'corporation_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_corporation_permission" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_id' is set
        if ('user_id' not in params or
                params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `update_corporation_permission`")  # noqa: E501
        # verify the required parameter 'corporation_id' is set
        if ('corporation_id' not in params or
                params['corporation_id'] is None):
            raise ValueError("Missing the required parameter `corporation_id` when calling `update_corporation_permission`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'user_id' in params:
            path_params['userId'] = params['user_id']  # noqa: E501
        if 'corporation_id' in params:
            path_params['corporationId'] = params['corporation_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Users/{userId}/permissions/corporations/{corporationId}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_current_user(self, **kwargs):  # noqa: E501
        """Updates the current user's information.  # noqa: E501

        Required Permissions: User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_current_user(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CurrentUserUpdateRequest body:
        :return: CurrentUserResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_current_user_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.update_current_user_with_http_info(**kwargs)  # noqa: E501
            return data

    def update_current_user_with_http_info(self, **kwargs):  # noqa: E501
        """Updates the current user's information.  # noqa: E501

        Required Permissions: User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_current_user_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CurrentUserUpdateRequest body:
        :return: CurrentUserResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_current_user" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Users/currentUser', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CurrentUserResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_location_permission(self, user_id, location_id, **kwargs):  # noqa: E501
        """Updates an existing user location permission  # noqa: E501

        Required Permissions: Location Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_location_permission(user_id, location_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: Id of the user (required)
        :param str location_id: Id of the corporation (required)
        :param LocationPermissionUpdateRequest body: Request to modify the permission
        :return: UserResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_location_permission_with_http_info(user_id, location_id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_location_permission_with_http_info(user_id, location_id, **kwargs)  # noqa: E501
            return data

    def update_location_permission_with_http_info(self, user_id, location_id, **kwargs):  # noqa: E501
        """Updates an existing user location permission  # noqa: E501

        Required Permissions: Location Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_location_permission_with_http_info(user_id, location_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: Id of the user (required)
        :param str location_id: Id of the corporation (required)
        :param LocationPermissionUpdateRequest body: Request to modify the permission
        :return: UserResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id', 'location_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_location_permission" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_id' is set
        if ('user_id' not in params or
                params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `update_location_permission`")  # noqa: E501
        # verify the required parameter 'location_id' is set
        if ('location_id' not in params or
                params['location_id'] is None):
            raise ValueError("Missing the required parameter `location_id` when calling `update_location_permission`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'user_id' in params:
            path_params['userId'] = params['user_id']  # noqa: E501
        if 'location_id' in params:
            path_params['locationId'] = params['location_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Users/{userId}/permissions/locations/{locationId}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_personal_access_token(self, token_id, **kwargs):  # noqa: E501
        """Update one of the current user's access tokens.  # noqa: E501

        Required Permissions: User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_personal_access_token(token_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str token_id: (required)
        :param PersonalAccessTokenUpdateRequest body:
        :return: PersonalAccessTokenResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_personal_access_token_with_http_info(token_id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_personal_access_token_with_http_info(token_id, **kwargs)  # noqa: E501
            return data

    def update_personal_access_token_with_http_info(self, token_id, **kwargs):  # noqa: E501
        """Update one of the current user's access tokens.  # noqa: E501

        Required Permissions: User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_personal_access_token_with_http_info(token_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str token_id: (required)
        :param PersonalAccessTokenUpdateRequest body:
        :return: PersonalAccessTokenResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['token_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_personal_access_token" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'token_id' is set
        if ('token_id' not in params or
                params['token_id'] is None):
            raise ValueError("Missing the required parameter `token_id` when calling `update_personal_access_token`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'token_id' in params:
            path_params['tokenId'] = params['token_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Users/currentUser/tokens/{tokenId}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PersonalAccessTokenResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_user(self, user_id, **kwargs):  # noqa: E501
        """Updates a user  # noqa: E501

        Required Permissions:  - System Admins can update any type of user  - Sentry can update sentry and below  - Corporation admins can update corporation admins and below  - Location admins can update location admins and below  - Users without admin rights cannot update users  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_user(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: ID of the user to update (required)
        :param UserUpdateRequest body: Request to update the user
        :return: UserResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_user_with_http_info(user_id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_user_with_http_info(user_id, **kwargs)  # noqa: E501
            return data

    def update_user_with_http_info(self, user_id, **kwargs):  # noqa: E501
        """Updates a user  # noqa: E501

        Required Permissions:  - System Admins can update any type of user  - Sentry can update sentry and below  - Corporation admins can update corporation admins and below  - Location admins can update location admins and below  - Users without admin rights cannot update users  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_user_with_http_info(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: ID of the user to update (required)
        :param UserUpdateRequest body: Request to update the user
        :return: UserResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_user" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_id' is set
        if ('user_id' not in params or
                params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `update_user`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'user_id' in params:
            path_params['userId'] = params['user_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Users/{userId}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_user_profile(self, user_id, **kwargs):  # noqa: E501
        """Updates a user's profile  # noqa: E501

        Required Permissions: User. A user may only update their own profile  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_user_profile(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: The user's ID (required)
        :param UserProfileUpdateRequest body: Request object used to update the profile
        :return: UserProfileResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_user_profile_with_http_info(user_id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_user_profile_with_http_info(user_id, **kwargs)  # noqa: E501
            return data

    def update_user_profile_with_http_info(self, user_id, **kwargs):  # noqa: E501
        """Updates a user's profile  # noqa: E501

        Required Permissions: User. A user may only update their own profile  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_user_profile_with_http_info(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: The user's ID (required)
        :param UserProfileUpdateRequest body: Request object used to update the profile
        :return: UserProfileResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_user_profile" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_id' is set
        if ('user_id' not in params or
                params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `update_user_profile`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'user_id' in params:
            path_params['userId'] = params['user_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Users/{userId}/profile', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserProfileResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class PropertyRequestChild(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'property_name': 'str',
        'property_value_type': 'PropertyValueType',
        'property_required': 'bool'
    }

    attribute_map = {
        'property_name': 'PropertyName',
        'property_value_type': 'PropertyValueType',
        'property_required': 'PropertyRequired'
    }

    def __init__(self, property_name=None, property_value_type=None, property_required=None):  # noqa: E501
        """PropertyRequestChild - a model defined in Swagger"""  # noqa: E501
        self._property_name = None
        self._property_value_type = None
        self._property_required = None
        self.discriminator = None
        self.property_name = property_name
        self.property_value_type = property_value_type
        self.property_required = property_required

    @property
    def property_name(self):
        """Gets the property_name of this PropertyRequestChild.  # noqa: E501


        :return: The property_name of this PropertyRequestChild.  # noqa: E501
        :rtype: str
        """
        return self._property_name

    @property_name.setter
    def property_name(self, property_name):
        """Sets the property_name of this PropertyRequestChild.


        :param property_name: The property_name of this PropertyRequestChild.  # noqa: E501
        :type: str
        """
        if property_name is None:
            raise ValueError("Invalid value for `property_name`, must not be `None`")  # noqa: E501

        self._property_name = property_name

    @property
    def property_value_type(self):
        """Gets the property_value_type of this PropertyRequestChild.  # noqa: E501


        :return: The property_value_type of this PropertyRequestChild.  # noqa: E501
        :rtype: PropertyValueType
        """
        return self._property_value_type

    @property_value_type.setter
    def property_value_type(self, property_value_type):
        """Sets the property_value_type of this PropertyRequestChild.


        :param property_value_type: The property_value_type of this PropertyRequestChild.  # noqa: E501
        :type: PropertyValueType
        """
        if property_value_type is None:
            raise ValueError("Invalid value for `property_value_type`, must not be `None`")  # noqa: E501

        self._property_value_type = property_value_type

    @property
    def property_required(self):
        """Gets the property_required of this PropertyRequestChild.  # noqa: E501


        :return: The property_required of this PropertyRequestChild.  # noqa: E501
        :rtype: bool
        """
        return self._property_required

    @property_required.setter
    def property_required(self, property_required):
        """Sets the property_required of this PropertyRequestChild.


        :param property_required: The property_required of this PropertyRequestChild.  # noqa: E501
        :type: bool
        """
        if property_required is None:
            raise ValueError("Invalid value for `property_required`, must not be `None`")  # noqa: E501

        self._property_required = property_required

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PropertyRequestChild, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PropertyRequestChild):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ThermalCameraResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'serial_number': 'int',
        'created': 'datetime',
        'updated': 'datetime',
        'active': 'bool',
        'location': 'LocationChild',
        'settings': 'ThermalCameraSettingsChild'
    }

    attribute_map = {
        'serial_number': 'SerialNumber',
        'created': 'Created',
        'updated': 'Updated',
        'active': 'Active',
        'location': 'Location',
        'settings': 'Settings'
    }

    def __init__(self, serial_number=None, created=None, updated=None, active=None, location=None, settings=None):  # noqa: E501
        """ThermalCameraResponse - a model defined in Swagger"""  # noqa: E501
        self._serial_number = None
        self._created = None
        self._updated = None
        self._active = None
        self._location = None
        self._settings = None
        self.discriminator = None
        self.serial_number = serial_number
        self.created = created
        self.updated = updated
        self.active = active
        self.location = location
        self.settings = settings

    @property
    def serial_number(self):
        """Gets the serial_number of this ThermalCameraResponse.  # noqa: E501


        :return: The serial_number of this ThermalCameraResponse.  # noqa: E501
        :rtype: int
        """
        return self._serial_number

    @serial_number.setter
    def serial_number(self, serial_number):
        """Sets the serial_number of this ThermalCameraResponse.


        :param serial_number: The serial_number of this ThermalCameraResponse.  # noqa: E501
        :type: int
        """
        if serial_number is None:
            raise ValueError("Invalid value for `serial_number`, must not be `None`")  # noqa: E501

        self._serial_number = serial_number

    @property
    def created(self):
        """Gets the created of this ThermalCameraResponse.  # noqa: E501


        :return: The created of this ThermalCameraResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this ThermalCameraResponse.


        :param created: The created of this ThermalCameraResponse.  # noqa: E501
        :type: datetime
        """
        if created is None:
            raise ValueError("Invalid value for `created`, must not be `None`")  # noqa: E501

        self._created = created

    @property
    def updated(self):
        """Gets the updated of this ThermalCameraResponse.  # noqa: E501


        :return: The updated of this ThermalCameraResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._updated

    @updated.setter
    def updated(self, updated):
        """Sets the updated of this ThermalCameraResponse.


        :param updated: The updated of this ThermalCameraResponse.  # noqa: E501
        :type: datetime
        """
        if updated is None:
            raise ValueError("Invalid value for `updated`, must not be `None`")  # noqa: E501

        self._updated = updated

    @property
    def active(self):
        """Gets the active of this ThermalCameraResponse.  # noqa: E501


        :return: The active of this ThermalCameraResponse.  # noqa: E501
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this ThermalCameraResponse.


        :param active: The active of this ThermalCameraResponse.  # noqa: E501
        :type: bool
        """
        if active is None:
            raise ValueError("Invalid value for `active`, must not be `None`")  # noqa: E501

        self._active = active

    @property
    def location(self):
        """Gets the location of this ThermalCameraResponse.  # noqa: E501


        :return: The location of this ThermalCameraResponse.  # noqa: E501
        :rtype: LocationChild
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this ThermalCameraResponse.


        :param location: The location of this ThermalCameraResponse.  # noqa: E501
        :type: LocationChild
        """
        if location is None:
            raise ValueError("Invalid value for `location`, must not be `None`")  # noqa: E501

        self._location = location

    @property
    def settings(self):
        """Gets the settings of this ThermalCameraResponse.  # noqa: E501


        :return: The settings of this ThermalCameraResponse.  # noqa: E501
        :rtype: ThermalCameraSettingsChild
        """
        return self._settings

    @settings.setter
    def settings(self, settings):
        """Sets the settings of this ThermalCameraResponse.


        :param settings: The settings of this ThermalCameraResponse.  # noqa: E501
        :type: ThermalCameraSettingsChild
        """
        if settings is None:
            raise ValueError("Invalid value for `settings`, must not be `None`")  # noqa: E501

        self._settings = settings

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ThermalCameraResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ThermalCameraResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class UserCorporationChild(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'corporation_id': 'str',
        'corporation_name': 'str',
        'corporation_abbreviation': 'str',
        'corporation_user_role': 'CorporationUserRole'
    }

    attribute_map = {
        'corporation_id': 'CorporationId',
        'corporation_name': 'CorporationName',
        'corporation_abbreviation': 'CorporationAbbreviation',
        'corporation_user_role': 'CorporationUserRole'
    }

    def __init__(self, corporation_id=None, corporation_name=None, corporation_abbreviation=None, corporation_user_role=None):  # noqa: E501
        """UserCorporationChild - a model defined in Swagger"""  # noqa: E501
        self._corporation_id = None
        self._corporation_name = None
        self._corporation_abbreviation = None
        self._corporation_user_role = None
        self.discriminator = None
        self.corporation_id = corporation_id
        self.corporation_name = corporation_name
        self.corporation_abbreviation = corporation_abbreviation
        self.corporation_user_role = corporation_user_role

    @property
    def corporation_id(self):
        """Gets the corporation_id of this UserCorporationChild.  # noqa: E501


        :return: The corporation_id of this UserCorporationChild.  # noqa: E501
        :rtype: str
        """
        return self._corporation_id

    @corporation_id.setter
    def corporation_id(self, corporation_id):
        """Sets the corporation_id of this UserCorporationChild.


        :param corporation_id: The corporation_id of this UserCorporationChild.  # noqa: E501
        :type: str
        """
        if corporation_id is None:
            raise ValueError("Invalid value for `corporation_id`, must not be `None`")  # noqa: E501

        self._corporation_id = corporation_id

    @property
    def corporation_name(self):
        """Gets the corporation_name of this UserCorporationChild.  # noqa: E501


        :return: The corporation_name of this UserCorporationChild.  # noqa: E501
        :rtype: str
        """
        return self._corporation_name

    @corporation_name.setter
    def corporation_name(self, corporation_name):
        """Sets the corporation_name of this UserCorporationChild.


        :param corporation_name: The corporation_name of this UserCorporationChild.  # noqa: E501
        :type: str
        """
        if corporation_name is None:
            raise ValueError("Invalid value for `corporation_name`, must not be `None`")  # noqa: E501

        self._corporation_name = corporation_name

    @property
    def corporation_abbreviation(self):
        """Gets the corporation_abbreviation of this UserCorporationChild.  # noqa: E501


        :return: The corporation_abbreviation of this UserCorporationChild.  # noqa: E501
        :rtype: str
        """
        return self._corporation_abbreviation

    @corporation_abbreviation.setter
    def corporation_abbreviation(self, corporation_abbreviation):
        """Sets the corporation_abbreviation of this UserCorporationChild.


        :param corporation_abbreviation: The corporation_abbreviation of this UserCorporationChild.  # noqa: E501
        :type: str
        """
        if corporation_abbreviation is None:
            raise ValueError("Invalid value for `corporation_abbreviation`, must not be `None`")  # noqa: E501

        self._corporation_abbreviation = corporation_abbreviation

    @property
    def corporation_user_role(self):
        """Gets the corporation_user_role of this UserCorporationChild.  # noqa: E501


        :return: The corporation_user_role of this UserCorporationChild.  # noqa: E501
        :rtype: CorporationUserRole
        """
        return self._corporation_user_role

    @corporation_user_role.setter
    def corporation_user_role(self, corporation_user_role):
        """Sets the corporation_user_role of this UserCorporationChild.


        :param corporation_user_role: The corporation_user_role of this UserCorporationChild.  # noqa: E501
        :type: CorporationUserRole
        """
        if corporation_user_role is None:
            raise ValueError("Invalid value for `corporation_user_role`, must not be `None`")  # noqa: E501

        self._corporation_user_role = corporation_user_role

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UserCorporationChild, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserCorporationChild):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class HeatmapReportRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'aggregate_level': 'HeatmapAggregateLevel',
        'hours_per_bin': 'int',
        'filter_id': 'str',
        'start_date': 'datetime',
        'end_date': 'datetime',
        'file_name': 'str'
    }

    attribute_map = {
        'aggregate_level': 'AggregateLevel',
        'hours_per_bin': 'HoursPerBin',
        'filter_id': 'FilterId',
        'start_date': 'StartDate',
        'end_date': 'EndDate',
        'file_name': 'FileName'
    }

    def __init__(self, aggregate_level=None, hours_per_bin=None, filter_id=None, start_date=None, end_date=None, file_name=None):  # noqa: E501
        """HeatmapReportRequest - a model defined in Swagger"""  # noqa: E501
        self._aggregate_level = None
        self._hours_per_bin = None
        self._filter_id = None
        self._start_date = None
        self._end_date = None
        self._file_name = None
        self.discriminator = None
        self.aggregate_level = aggregate_level
        self.hours_per_bin = hours_per_bin
        if filter_id is not None:
            self.filter_id = filter_id
        self.start_date = start_date
        self.end_date = end_date
        self.file_name = file_name

    @property
    def aggregate_level(self):
        """Gets the aggregate_level of this HeatmapReportRequest.  # noqa: E501


        :return: The aggregate_level of this HeatmapReportRequest.  # noqa: E501
        :rtype: HeatmapAggregateLevel
        """
        return self._aggregate_level

    @aggregate_level.setter
    def aggregate_level(self, aggregate_level):
        """Sets the aggregate_level of this HeatmapReportRequest.


        :param aggregate_level: The aggregate_level of this HeatmapReportRequest.  # noqa: E501
        :type: HeatmapAggregateLevel
        """
        if aggregate_level is None:
            raise ValueError("Invalid value for `aggregate_level`, must not be `None`")  # noqa: E501

        self._aggregate_level = aggregate_level

    @property
    def hours_per_bin(self):
        """Gets the hours_per_bin of this HeatmapReportRequest.  # noqa: E501

        The size (in hours) to use to split the given time range into parts  # noqa: E501

        :return: The hours_per_bin of this HeatmapReportRequest.  # noqa: E501
        :rtype: int
        """
        return self._hours_per_bin

    @hours_per_bin.setter
    def hours_per_bin(self, hours_per_bin):
        """Sets the hours_per_bin of this HeatmapReportRequest.

        The size (in hours) to use to split the given time range into parts  # noqa: E501

        :param hours_per_bin: The hours_per_bin of this HeatmapReportRequest.  # noqa: E501
        :type: int
        """
        if hours_per_bin is None:
            raise ValueError("Invalid value for `hours_per_bin`, must not be `None`")  # noqa: E501

        self._hours_per_bin = hours_per_bin

    @property
    def filter_id(self):
        """Gets the filter_id of this HeatmapReportRequest.  # noqa: E501

        The filter to use. Optional  # noqa: E501

        :return: The filter_id of this HeatmapReportRequest.  # noqa: E501
        :rtype: str
        """
        return self._filter_id

    @filter_id.setter
    def filter_id(self, filter_id):
        """Sets the filter_id of this HeatmapReportRequest.

        The filter to use. Optional  # noqa: E501

        :param filter_id: The filter_id of this HeatmapReportRequest.  # noqa: E501
        :type: str
        """

        self._filter_id = filter_id

    @property
    def start_date(self):
        """Gets the start_date of this HeatmapReportRequest.  # noqa: E501

        The start date of the time range to get the report for. Nullable so Required can catch nulls, will not  be null later.  # noqa: E501

        :return: The start_date of this HeatmapReportRequest.  # noqa: E501
        :rtype: datetime
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this HeatmapReportRequest.

        The start date of the time range to get the report for. Nullable so Required can catch nulls, will not  be null later.  # noqa: E501

        :param start_date: The start_date of this HeatmapReportRequest.  # noqa: E501
        :type: datetime
        """
        if start_date is None:
            raise ValueError("Invalid value for `start_date`, must not be `None`")  # noqa: E501

        self._start_date = start_date

    @property
    def end_date(self):
        """Gets the end_date of this HeatmapReportRequest.  # noqa: E501

        The end date of the time range to get the values for. Nullable so Required can catch nulls, will not  be null later.  # noqa: E501

        :return: The end_date of this HeatmapReportRequest.  # noqa: E501
        :rtype: datetime
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this HeatmapReportRequest.

        The end date of the time range to get the values for. Nullable so Required can catch nulls, will not  be null later.  # noqa: E501

        :param end_date: The end_date of this HeatmapReportRequest.  # noqa: E501
        :type: datetime
        """
        if end_date is None:
            raise ValueError("Invalid value for `end_date`, must not be `None`")  # noqa: E501

        self._end_date = end_date

    @property
    def file_name(self):
        """Gets the file_name of this HeatmapReportRequest.  # noqa: E501

        The filename to use for the report  # noqa: E501

        :return: The file_name of this HeatmapReportRequest.  # noqa: E501
        :rtype: str
        """
        return self._file_name

    @file_name.setter
    def file_name(self, file_name):
        """Sets the file_name of this HeatmapReportRequest.

        The filename to use for the report  # noqa: E501

        :param file_name: The file_name of this HeatmapReportRequest.  # noqa: E501
        :type: str
        """
        if file_name is None:
            raise ValueError("Invalid value for `file_name`, must not be `None`")  # noqa: E501

        self._file_name = file_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(HeatmapReportRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HeatmapReportRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class UserCreateRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'first_name': 'str',
        'last_name': 'str',
        'email': 'str',
        'application_role_code': 'ApplicationRoleCode',
        'corporations': 'list[UserRequestCorporationChild]',
        'locations': 'list[UserRequestLocationChild]'
    }

    attribute_map = {
        'first_name': 'FirstName',
        'last_name': 'LastName',
        'email': 'Email',
        'application_role_code': 'ApplicationRoleCode',
        'corporations': 'Corporations',
        'locations': 'Locations'
    }

    def __init__(self, first_name=None, last_name=None, email=None, application_role_code=None, corporations=None, locations=None):  # noqa: E501
        """UserCreateRequest - a model defined in Swagger"""  # noqa: E501
        self._first_name = None
        self._last_name = None
        self._email = None
        self._application_role_code = None
        self._corporations = None
        self._locations = None
        self.discriminator = None
        self.first_name = first_name
        self.last_name = last_name
        self.email = email
        self.application_role_code = application_role_code
        if corporations is not None:
            self.corporations = corporations
        if locations is not None:
            self.locations = locations

    @property
    def first_name(self):
        """Gets the first_name of this UserCreateRequest.  # noqa: E501

        The user's first name  # noqa: E501

        :return: The first_name of this UserCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this UserCreateRequest.

        The user's first name  # noqa: E501

        :param first_name: The first_name of this UserCreateRequest.  # noqa: E501
        :type: str
        """
        if first_name is None:
            raise ValueError("Invalid value for `first_name`, must not be `None`")  # noqa: E501

        self._first_name = first_name

    @property
    def last_name(self):
        """Gets the last_name of this UserCreateRequest.  # noqa: E501

        The user's last name  # noqa: E501

        :return: The last_name of this UserCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this UserCreateRequest.

        The user's last name  # noqa: E501

        :param last_name: The last_name of this UserCreateRequest.  # noqa: E501
        :type: str
        """
        if last_name is None:
            raise ValueError("Invalid value for `last_name`, must not be `None`")  # noqa: E501

        self._last_name = last_name

    @property
    def email(self):
        """Gets the email of this UserCreateRequest.  # noqa: E501

        User's email  # noqa: E501

        :return: The email of this UserCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this UserCreateRequest.

        User's email  # noqa: E501

        :param email: The email of this UserCreateRequest.  # noqa: E501
        :type: str
        """
        if email is None:
            raise ValueError("Invalid value for `email`, must not be `None`")  # noqa: E501

        self._email = email

    @property
    def application_role_code(self):
        """Gets the application_role_code of this UserCreateRequest.  # noqa: E501


        :return: The application_role_code of this UserCreateRequest.  # noqa: E501
        :rtype: ApplicationRoleCode
        """
        return self._application_role_code

    @application_role_code.setter
    def application_role_code(self, application_role_code):
        """Sets the application_role_code of this UserCreateRequest.


        :param application_role_code: The application_role_code of this UserCreateRequest.  # noqa: E501
        :type: ApplicationRoleCode
        """
        if application_role_code is None:
            raise ValueError("Invalid value for `application_role_code`, must not be `None`")  # noqa: E501

        self._application_role_code = application_role_code

    @property
    def corporations(self):
        """Gets the corporations of this UserCreateRequest.  # noqa: E501

        The corporations the user belongs to. Saas users should not belong to any corporations  # noqa: E501

        :return: The corporations of this UserCreateRequest.  # noqa: E501
        :rtype: list[UserRequestCorporationChild]
        """
        return self._corporations

    @corporations.setter
    def corporations(self, corporations):
        """Sets the corporations of this UserCreateRequest.

        The corporations the user belongs to. Saas users should not belong to any corporations  # noqa: E501

        :param corporations: The corporations of this UserCreateRequest.  # noqa: E501
        :type: list[UserRequestCorporationChild]
        """

        self._corporations = corporations

    @property
    def locations(self):
        """Gets the locations of this UserCreateRequest.  # noqa: E501

        The locations the user belongs to. Saas users should not belong to any locations  # noqa: E501

        :return: The locations of this UserCreateRequest.  # noqa: E501
        :rtype: list[UserRequestLocationChild]
        """
        return self._locations

    @locations.setter
    def locations(self, locations):
        """Sets the locations of this UserCreateRequest.

        The locations the user belongs to. Saas users should not belong to any locations  # noqa: E501

        :param locations: The locations of this UserCreateRequest.  # noqa: E501
        :type: list[UserRequestLocationChild]
        """

        self._locations = locations

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UserCreateRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserCreateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.models.hub_power_type import HubPowerType  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestHubPowerType(unittest.TestCase):
    """HubPowerType unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testHubPowerType(self):
        """Test HubPowerType"""
        # FIXME: construct object with mandatory attributes with example values
        # model = smart_diagnostics_client.models.hub_power_type.HubPowerType()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.sub_systems_api import SubSystemsApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestSubSystemsApi(unittest.TestCase):
    """SubSystemsApi unit test stubs"""

    def setUp(self):
        self.api = SubSystemsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_sub_system(self):
        """Test case for create_sub_system

        Creates a subSystem  # noqa: E501
        """
        pass

    def test_delete_sub_system(self):
        """Test case for delete_sub_system

        Deletes a subSystem  # noqa: E501
        """
        pass

    def test_get_sub_system(self):
        """Test case for get_sub_system

        Gets a subSystem  # noqa: E501
        """
        pass

    def test_get_sub_systems(self):
        """Test case for get_sub_systems

        Gets subSystems  # noqa: E501
        """
        pass

    def test_move_sub_system(self):
        """Test case for move_sub_system

        Moves a subSystem  # noqa: E501
        """
        pass

    def test_update_sub_system(self):
        """Test case for update_sub_system

        Updates a subSystem  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ActivityEventDetailResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'title': 'str',
        'description': 'str',
        'note': 'str',
        'start_date_time': 'datetime',
        'end_date_time': 'datetime',
        'document': 'DocumentChild',
        'category': 'ActivityEventCategoryChild',
        'subcategories': 'list[ActivityEventSubcategoryChild]',
        'binds': 'list[ActivityEventBindChild]',
        'fields': 'list[ActivityEventFieldEntryChild]',
        'assignments': 'list[ActivityEventAssignmentChild]'
    }

    attribute_map = {
        'id': 'Id',
        'title': 'Title',
        'description': 'Description',
        'note': 'Note',
        'start_date_time': 'StartDateTime',
        'end_date_time': 'EndDateTime',
        'document': 'Document',
        'category': 'Category',
        'subcategories': 'Subcategories',
        'binds': 'Binds',
        'fields': 'Fields',
        'assignments': 'Assignments'
    }

    def __init__(self, id=None, title=None, description=None, note=None, start_date_time=None, end_date_time=None, document=None, category=None, subcategories=None, binds=None, fields=None, assignments=None):  # noqa: E501
        """ActivityEventDetailResponse - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._title = None
        self._description = None
        self._note = None
        self._start_date_time = None
        self._end_date_time = None
        self._document = None
        self._category = None
        self._subcategories = None
        self._binds = None
        self._fields = None
        self._assignments = None
        self.discriminator = None
        self.id = id
        self.title = title
        if description is not None:
            self.description = description
        if note is not None:
            self.note = note
        self.start_date_time = start_date_time
        if end_date_time is not None:
            self.end_date_time = end_date_time
        if document is not None:
            self.document = document
        self.category = category
        self.subcategories = subcategories
        self.binds = binds
        self.fields = fields
        self.assignments = assignments

    @property
    def id(self):
        """Gets the id of this ActivityEventDetailResponse.  # noqa: E501

        Activity event id  # noqa: E501

        :return: The id of this ActivityEventDetailResponse.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ActivityEventDetailResponse.

        Activity event id  # noqa: E501

        :param id: The id of this ActivityEventDetailResponse.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def title(self):
        """Gets the title of this ActivityEventDetailResponse.  # noqa: E501

        The title of activity event  # noqa: E501

        :return: The title of this ActivityEventDetailResponse.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this ActivityEventDetailResponse.

        The title of activity event  # noqa: E501

        :param title: The title of this ActivityEventDetailResponse.  # noqa: E501
        :type: str
        """
        if title is None:
            raise ValueError("Invalid value for `title`, must not be `None`")  # noqa: E501

        self._title = title

    @property
    def description(self):
        """Gets the description of this ActivityEventDetailResponse.  # noqa: E501

        The description of what occurred during the activity event.  # noqa: E501

        :return: The description of this ActivityEventDetailResponse.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ActivityEventDetailResponse.

        The description of what occurred during the activity event.  # noqa: E501

        :param description: The description of this ActivityEventDetailResponse.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def note(self):
        """Gets the note of this ActivityEventDetailResponse.  # noqa: E501

        Note for activity event  # noqa: E501

        :return: The note of this ActivityEventDetailResponse.  # noqa: E501
        :rtype: str
        """
        return self._note

    @note.setter
    def note(self, note):
        """Sets the note of this ActivityEventDetailResponse.

        Note for activity event  # noqa: E501

        :param note: The note of this ActivityEventDetailResponse.  # noqa: E501
        :type: str
        """

        self._note = note

    @property
    def start_date_time(self):
        """Gets the start_date_time of this ActivityEventDetailResponse.  # noqa: E501

        Activity event start date / time  # noqa: E501

        :return: The start_date_time of this ActivityEventDetailResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._start_date_time

    @start_date_time.setter
    def start_date_time(self, start_date_time):
        """Sets the start_date_time of this ActivityEventDetailResponse.

        Activity event start date / time  # noqa: E501

        :param start_date_time: The start_date_time of this ActivityEventDetailResponse.  # noqa: E501
        :type: datetime
        """
        if start_date_time is None:
            raise ValueError("Invalid value for `start_date_time`, must not be `None`")  # noqa: E501

        self._start_date_time = start_date_time

    @property
    def end_date_time(self):
        """Gets the end_date_time of this ActivityEventDetailResponse.  # noqa: E501

        Activity event end date / time (if available)  # noqa: E501

        :return: The end_date_time of this ActivityEventDetailResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._end_date_time

    @end_date_time.setter
    def end_date_time(self, end_date_time):
        """Sets the end_date_time of this ActivityEventDetailResponse.

        Activity event end date / time (if available)  # noqa: E501

        :param end_date_time: The end_date_time of this ActivityEventDetailResponse.  # noqa: E501
        :type: datetime
        """

        self._end_date_time = end_date_time

    @property
    def document(self):
        """Gets the document of this ActivityEventDetailResponse.  # noqa: E501


        :return: The document of this ActivityEventDetailResponse.  # noqa: E501
        :rtype: DocumentChild
        """
        return self._document

    @document.setter
    def document(self, document):
        """Sets the document of this ActivityEventDetailResponse.


        :param document: The document of this ActivityEventDetailResponse.  # noqa: E501
        :type: DocumentChild
        """

        self._document = document

    @property
    def category(self):
        """Gets the category of this ActivityEventDetailResponse.  # noqa: E501


        :return: The category of this ActivityEventDetailResponse.  # noqa: E501
        :rtype: ActivityEventCategoryChild
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this ActivityEventDetailResponse.


        :param category: The category of this ActivityEventDetailResponse.  # noqa: E501
        :type: ActivityEventCategoryChild
        """
        if category is None:
            raise ValueError("Invalid value for `category`, must not be `None`")  # noqa: E501

        self._category = category

    @property
    def subcategories(self):
        """Gets the subcategories of this ActivityEventDetailResponse.  # noqa: E501

        List of subcategories  # noqa: E501

        :return: The subcategories of this ActivityEventDetailResponse.  # noqa: E501
        :rtype: list[ActivityEventSubcategoryChild]
        """
        return self._subcategories

    @subcategories.setter
    def subcategories(self, subcategories):
        """Sets the subcategories of this ActivityEventDetailResponse.

        List of subcategories  # noqa: E501

        :param subcategories: The subcategories of this ActivityEventDetailResponse.  # noqa: E501
        :type: list[ActivityEventSubcategoryChild]
        """
        if subcategories is None:
            raise ValueError("Invalid value for `subcategories`, must not be `None`")  # noqa: E501

        self._subcategories = subcategories

    @property
    def binds(self):
        """Gets the binds of this ActivityEventDetailResponse.  # noqa: E501

        List of binds (entity associations)  # noqa: E501

        :return: The binds of this ActivityEventDetailResponse.  # noqa: E501
        :rtype: list[ActivityEventBindChild]
        """
        return self._binds

    @binds.setter
    def binds(self, binds):
        """Sets the binds of this ActivityEventDetailResponse.

        List of binds (entity associations)  # noqa: E501

        :param binds: The binds of this ActivityEventDetailResponse.  # noqa: E501
        :type: list[ActivityEventBindChild]
        """
        if binds is None:
            raise ValueError("Invalid value for `binds`, must not be `None`")  # noqa: E501

        self._binds = binds

    @property
    def fields(self):
        """Gets the fields of this ActivityEventDetailResponse.  # noqa: E501

        List of field / field entries  # noqa: E501

        :return: The fields of this ActivityEventDetailResponse.  # noqa: E501
        :rtype: list[ActivityEventFieldEntryChild]
        """
        return self._fields

    @fields.setter
    def fields(self, fields):
        """Sets the fields of this ActivityEventDetailResponse.

        List of field / field entries  # noqa: E501

        :param fields: The fields of this ActivityEventDetailResponse.  # noqa: E501
        :type: list[ActivityEventFieldEntryChild]
        """
        if fields is None:
            raise ValueError("Invalid value for `fields`, must not be `None`")  # noqa: E501

        self._fields = fields

    @property
    def assignments(self):
        """Gets the assignments of this ActivityEventDetailResponse.  # noqa: E501

        List of assignments (created, updated)  # noqa: E501

        :return: The assignments of this ActivityEventDetailResponse.  # noqa: E501
        :rtype: list[ActivityEventAssignmentChild]
        """
        return self._assignments

    @assignments.setter
    def assignments(self, assignments):
        """Sets the assignments of this ActivityEventDetailResponse.

        List of assignments (created, updated)  # noqa: E501

        :param assignments: The assignments of this ActivityEventDetailResponse.  # noqa: E501
        :type: list[ActivityEventAssignmentChild]
        """
        if assignments is None:
            raise ValueError("Invalid value for `assignments`, must not be `None`")  # noqa: E501

        self._assignments = assignments

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ActivityEventDetailResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ActivityEventDetailResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class DescendantChild(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'child_id': 'str',
        'child_name': 'str',
        'child_abbreviation': 'str',
        'child_type': 'GroupTypeCodes',
        'child_sort_order': 'int',
        'child_has_children': 'bool',
        'child_alarm_severity_level': 'int',
        'child_is_paused': 'bool',
        'child_is_snoozed': 'bool'
    }

    attribute_map = {
        'child_id': 'ChildId',
        'child_name': 'ChildName',
        'child_abbreviation': 'ChildAbbreviation',
        'child_type': 'ChildType',
        'child_sort_order': 'ChildSortOrder',
        'child_has_children': 'ChildHasChildren',
        'child_alarm_severity_level': 'ChildAlarmSeverityLevel',
        'child_is_paused': 'ChildIsPaused',
        'child_is_snoozed': 'ChildIsSnoozed'
    }

    def __init__(self, child_id=None, child_name=None, child_abbreviation=None, child_type=None, child_sort_order=None, child_has_children=None, child_alarm_severity_level=None, child_is_paused=None, child_is_snoozed=None):  # noqa: E501
        """DescendantChild - a model defined in Swagger"""  # noqa: E501
        self._child_id = None
        self._child_name = None
        self._child_abbreviation = None
        self._child_type = None
        self._child_sort_order = None
        self._child_has_children = None
        self._child_alarm_severity_level = None
        self._child_is_paused = None
        self._child_is_snoozed = None
        self.discriminator = None
        self.child_id = child_id
        self.child_name = child_name
        if child_abbreviation is not None:
            self.child_abbreviation = child_abbreviation
        self.child_type = child_type
        self.child_sort_order = child_sort_order
        self.child_has_children = child_has_children
        if child_alarm_severity_level is not None:
            self.child_alarm_severity_level = child_alarm_severity_level
        self.child_is_paused = child_is_paused
        self.child_is_snoozed = child_is_snoozed

    @property
    def child_id(self):
        """Gets the child_id of this DescendantChild.  # noqa: E501


        :return: The child_id of this DescendantChild.  # noqa: E501
        :rtype: str
        """
        return self._child_id

    @child_id.setter
    def child_id(self, child_id):
        """Sets the child_id of this DescendantChild.


        :param child_id: The child_id of this DescendantChild.  # noqa: E501
        :type: str
        """
        if child_id is None:
            raise ValueError("Invalid value for `child_id`, must not be `None`")  # noqa: E501

        self._child_id = child_id

    @property
    def child_name(self):
        """Gets the child_name of this DescendantChild.  # noqa: E501


        :return: The child_name of this DescendantChild.  # noqa: E501
        :rtype: str
        """
        return self._child_name

    @child_name.setter
    def child_name(self, child_name):
        """Sets the child_name of this DescendantChild.


        :param child_name: The child_name of this DescendantChild.  # noqa: E501
        :type: str
        """
        if child_name is None:
            raise ValueError("Invalid value for `child_name`, must not be `None`")  # noqa: E501

        self._child_name = child_name

    @property
    def child_abbreviation(self):
        """Gets the child_abbreviation of this DescendantChild.  # noqa: E501


        :return: The child_abbreviation of this DescendantChild.  # noqa: E501
        :rtype: str
        """
        return self._child_abbreviation

    @child_abbreviation.setter
    def child_abbreviation(self, child_abbreviation):
        """Sets the child_abbreviation of this DescendantChild.


        :param child_abbreviation: The child_abbreviation of this DescendantChild.  # noqa: E501
        :type: str
        """

        self._child_abbreviation = child_abbreviation

    @property
    def child_type(self):
        """Gets the child_type of this DescendantChild.  # noqa: E501


        :return: The child_type of this DescendantChild.  # noqa: E501
        :rtype: GroupTypeCodes
        """
        return self._child_type

    @child_type.setter
    def child_type(self, child_type):
        """Sets the child_type of this DescendantChild.


        :param child_type: The child_type of this DescendantChild.  # noqa: E501
        :type: GroupTypeCodes
        """
        if child_type is None:
            raise ValueError("Invalid value for `child_type`, must not be `None`")  # noqa: E501

        self._child_type = child_type

    @property
    def child_sort_order(self):
        """Gets the child_sort_order of this DescendantChild.  # noqa: E501


        :return: The child_sort_order of this DescendantChild.  # noqa: E501
        :rtype: int
        """
        return self._child_sort_order

    @child_sort_order.setter
    def child_sort_order(self, child_sort_order):
        """Sets the child_sort_order of this DescendantChild.


        :param child_sort_order: The child_sort_order of this DescendantChild.  # noqa: E501
        :type: int
        """
        if child_sort_order is None:
            raise ValueError("Invalid value for `child_sort_order`, must not be `None`")  # noqa: E501

        self._child_sort_order = child_sort_order

    @property
    def child_has_children(self):
        """Gets the child_has_children of this DescendantChild.  # noqa: E501


        :return: The child_has_children of this DescendantChild.  # noqa: E501
        :rtype: bool
        """
        return self._child_has_children

    @child_has_children.setter
    def child_has_children(self, child_has_children):
        """Sets the child_has_children of this DescendantChild.


        :param child_has_children: The child_has_children of this DescendantChild.  # noqa: E501
        :type: bool
        """
        if child_has_children is None:
            raise ValueError("Invalid value for `child_has_children`, must not be `None`")  # noqa: E501

        self._child_has_children = child_has_children

    @property
    def child_alarm_severity_level(self):
        """Gets the child_alarm_severity_level of this DescendantChild.  # noqa: E501


        :return: The child_alarm_severity_level of this DescendantChild.  # noqa: E501
        :rtype: int
        """
        return self._child_alarm_severity_level

    @child_alarm_severity_level.setter
    def child_alarm_severity_level(self, child_alarm_severity_level):
        """Sets the child_alarm_severity_level of this DescendantChild.


        :param child_alarm_severity_level: The child_alarm_severity_level of this DescendantChild.  # noqa: E501
        :type: int
        """

        self._child_alarm_severity_level = child_alarm_severity_level

    @property
    def child_is_paused(self):
        """Gets the child_is_paused of this DescendantChild.  # noqa: E501


        :return: The child_is_paused of this DescendantChild.  # noqa: E501
        :rtype: bool
        """
        return self._child_is_paused

    @child_is_paused.setter
    def child_is_paused(self, child_is_paused):
        """Sets the child_is_paused of this DescendantChild.


        :param child_is_paused: The child_is_paused of this DescendantChild.  # noqa: E501
        :type: bool
        """
        if child_is_paused is None:
            raise ValueError("Invalid value for `child_is_paused`, must not be `None`")  # noqa: E501

        self._child_is_paused = child_is_paused

    @property
    def child_is_snoozed(self):
        """Gets the child_is_snoozed of this DescendantChild.  # noqa: E501


        :return: The child_is_snoozed of this DescendantChild.  # noqa: E501
        :rtype: bool
        """
        return self._child_is_snoozed

    @child_is_snoozed.setter
    def child_is_snoozed(self, child_is_snoozed):
        """Sets the child_is_snoozed of this DescendantChild.


        :param child_is_snoozed: The child_is_snoozed of this DescendantChild.  # noqa: E501
        :type: bool
        """
        if child_is_snoozed is None:
            raise ValueError("Invalid value for `child_is_snoozed`, must not be `None`")  # noqa: E501

        self._child_is_snoozed = child_is_snoozed

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DescendantChild, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DescendantChild):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
